==> web-6.0.0.tgz: package/lib/input/Search.js <==
import * as React from "react";
import { VelocityComponent } from "velocity-react";
import { SvgIcon } from "../my-icon/index";
class Search extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            searching: false,
            keyword: "",
            preField: this.props.field
        };
        this.toggleSearch = () => {
            const { keyword } = this.state;
            if (!keyword) {
                return;
            }
            const { field, searchHandle } = this.props;
            this.setState({
                searching: true,
            });
            searchHandle(keyword, field);
        };
        this.closeSearch = () => {
            this.setState({
                searching: false,
                keyword: "",
            });
            const { closeHandle, field } = this.props;
            if (closeHandle) {
                closeHandle(field);
            }
        };
        this.keyPress = (e) => {
            if (e.key === "Enter") {
                this.toggleSearch();
            }
        };
        this.changeFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value.trim();
            this.setState({
                keyword: value,
            });
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.field !== preState.preField) {
            const { closeHandle, field } = nextProps;
            if (closeHandle) {
                closeHandle(field);
            }
            return {
                searching: false,
                keyword: "",
                preField: nextProps.field
            };
        }
        else {
            return null;
        }
    }
    render() {
        const { searching, keyword } = this.state;
        const { tip, width } = this.props;
        const styleObj = width ? { width } : undefined;
        return (React.createElement("div", { className: "m-search", style: styleObj },
            React.createElement("input", { type: "text", className: "s-inp", value: keyword, placeholder: tip, onChange: this.changeFn, onKeyDown: this.keyPress }),
            React.createElement(VelocityComponent, { animation: searching ? "fadeIn" : "fadeOut" },
                React.createElement("span", { className: "m-search-close", onClick: this.closeSearch },
                    React.createElement(SvgIcon, { className: "close" }))),
            React.createElement("span", { className: "j-search-icon", onClick: this.toggleSearch },
                React.createElement(SvgIcon, { className: "search", size: "middle" }))));
    }
}
Search.defaultProps = {
    tip: "查询搜索结果...",
};
export default Search;

==> web-8.0.0.tgz: package/lib/input/Search.js <==
import * as React from "react";
import { Animate } from "../animate/index";
import { SvgIcon } from "../my-icon/index";
class Search extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            searching: false,
            keyword: "",
            preField: this.props.field
        };
        this.toggleSearch = () => {
            const { keyword } = this.state;
            if (!keyword) {
                return;
            }
            const { field, searchHandle } = this.props;
            this.setState({
                searching: true,
            });
            searchHandle(keyword, field);
        };
        this.closeSearch = () => {
            this.setState({
                searching: false,
                keyword: "",
            });
            const { closeHandle, field } = this.props;
            if (closeHandle) {
                closeHandle(field);
            }
        };
        this.keyPress = (e) => {
            if (e.key === "Enter") {
                this.toggleSearch();
            }
        };
        this.changeFn = (e) => {
            const dom = e.currentTarget;
            const value = dom.value.trim();
            this.setState({
                keyword: value,
            });
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.field !== preState.preField) {
            const { closeHandle, field } = nextProps;
            if (closeHandle) {
                closeHandle(field);
            }
            return {
                searching: false,
                keyword: "",
                preField: nextProps.field
            };
        }
        else {
            return null;
        }
    }
    render() {
        const { searching, keyword } = this.state;
        const { tip, width } = this.props;
        const styleObj = width ? { width } : undefined;
        return (React.createElement("div", { className: "m-search", style: styleObj },
            React.createElement("input", { type: "text", className: "s-inp", value: keyword, placeholder: tip, onChange: this.changeFn, onKeyDown: this.keyPress }),
            React.createElement(Animate, { animation: searching ? "fadeIn" : "fadeOut", spanWrapEle: true },
                React.createElement("span", { className: "m-search-close", onClick: this.closeSearch },
                    React.createElement(SvgIcon, { className: "close" }))),
            React.createElement("span", { className: "j-search-icon", onClick: this.toggleSearch },
                React.createElement(SvgIcon, { className: "search", size: "middle" }))));
    }
}
Search.defaultProps = {
    tip: "查询搜索结果...",
};
export default Search;
